# -*- coding: utf-8 -*-
"""
certbot_dns_transip package.

Imports all parts from certbot_dns_transip here
"""
from ._version import __version__

__author__ = '''Wim Fournier'''
__email__ = '''wim@fournier.nl'''

# This is to 'use' the module(s), so lint doesn't complain
assert __version__
